Dominance Analysis Package

This package can be used for dominance analysis on the given data-set.

Please follow the github repository for detailed description [here](https://bhagatsajan0073.github.io/dominance-analysis).